@@ -11,9 +11,9 @@ __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
 from interfaces import IDictAnnotation
-from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitileSubscriberBase
+from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitleSubscriberBase
 
-class DictAnnotation2TitleSubscriber( AnyTitileSubscriberBase ) :
+class DictAnnotation2TitleSubscriber( AnyTitleSubscriberBase ) :
 
     order = 2
 
